@@ -37,6 +37,7 @@
 #include <libintl.h>
 #include <unistd.h>
 #include <fstream>
+#include <array>
 
 #include "../config.hpp"
 
@@ -474,9 +475,21 @@ class Model_ListCfg :
 				FILE* proxyBinTarget = fopen((this->env->cfg_dir+"/bin/grubcfg_proxy").c_str(), "w");
 				if (proxyBinTarget){
 					int c;
-					while ((c = fgetc(proxyBinSource)) != EOF){
-						fputc(c, proxyBinTarget);
-					}
+					fputs(
+						"#!/bin/sh\n"
+						"if [ -e ",
+						proxyBinTarget
+					);
+					fputs(LIBDIR, proxyBinTarget);
+					fputs("/grubcfg-proxy ] ; then\n"
+						"    cat | ", proxyBinTarget);
+					fputs(LIBDIR, proxyBinTarget);
+					fputs("/grubcfg-proxy \"$@\"\n"
+						"else\n"
+						"    cat\n"
+						"fi\n",
+						proxyBinTarget
+					);
 					fclose(proxyBinTarget);
 					chmod((this->env->cfg_dir+"/bin/grubcfg_proxy").c_str(), 0755);
 				} else {
